---
title: 修改用户信息
sidebar_position: 20
---

融云服务端不提供用户信息托管维护服务。如果应用程序需要修改在 IMKit SDK UI 显示的用户及群组的头像、昵称等信息，必须主动调用 IMKit 提供的方法更新信息。

本文详细描述了如何修改 IMKit SDK 设置的用户、群组的头像、昵称等信息。

## 更新当前登录用户昵称和头像

`updateUserProfile` 用于更新用户的昵称、头像。支持异步返回用户信息对象。

```js
const info = {
  id: '当前用户 id', // 可在 connect 连接成功后获取
  name: '用户名称',
  portraitUri: '用户头像 URL'
}
imkit.updateUserProfile(info)
```

**info 参数说明**

|       参数     | 类型   | 必填 |     说明   |
|:------------- |:-------|:--- |:---------- |
| id            | string | 是  | 用户 UserId |
| name          | string | 是  | 用户昵称 |
| portraitUri   | string | 否  | 用户头像 URI |

## 更新当前页面会话的信息

:::tip

 仅支持修改当前页面上会话的信息。修改当前页面不存在或未加载的会话则更新无效。当前没有选中会话则仅修改内存态对应会话信息。
:::


`updateConversationProfile` 用于修改当前页面中会话的昵称、头像、群成员数量，适用于单聊会话、群聊会话。**注意**，群成员数量（`memberCount`）仅在群组会话时生效。

```js
const conversation = {
  // 会话类型，单聊为:PRIVATE，群聊为:GROUP，可从 conversation 中获取
  conversationType: ConversationType.PRIVATE,
  // 群聊为群组 Id，单聊为 userId，可从 conversation 中获取
  targetId: '目标 Id'
}

const info = {
  conversationType: 1,
  targetId: '目标 Id', // 群组为群组 Id,单聊为 userId
  name: '用户名称',
  portraitUri: '用户头像 URL'
}
imkit.updateConversationProfile(conversation, info)
```

**conversation 属性说明**

| 名称             | 参数   | 必传 | 说明     |
| ---------------- | ------ | ---- | -------- |
| conversationType | string | 是   | 会话类型 |
| targetId         | string | 是   | 目标 Id  |

**info 参数说明**

|       参数        | 类型             | 必填 |     说明   |
|:---------------- |:-----------------|:--- |:---------- |
| conversationType | ConversationType | 是  | 会话类型，可在参数 `conversation` 中获取。|
| targetId         | string           | 是  | 目标 ID，可在参数 `conversation` 中获取。 |
| name             | string           | 否  | 会话昵称 |
| portraitUri      | string           | 否  | 会话头像 URI |
| memberCount      | number           | 否  | 群成员数量，此属性仅对群组有效。 |

## 修改全部群成员信息

`updateGroupMembers` 用于修改群聊会话的全部群组成员的昵称、头像。仅支持全量修改群组信息。

- 如果已选中待修改的群聊会话，修改当前选中的群聊会话的成员信息，SDK 会刷新页面，显示修改后的数据。
- 如果修改时没有任何群聊会话被选中，则修改群聊会话成员信息不会触发页面刷新。修改后的数据会保存在内存中，只要内存数据未丢失，后续切换到该会话时不需要再次修改，页面直接展示最新数据。

`updateGroupMembers`  仅支持全量修改群组成员信息，调用必须传递全部群成员信息。如果仅需修改部分数据，调用时也必须传递全部群成员信息。假设群组中有 `groupMemberUserId1` 和 `groupMemberUserId2` 两位用户：

```js
import { ConversationType } from '@rongcloud/imlib-next'
const conversation = {
  // 会话类型，群聊为:GROUP，可从 conversation 中获取
  conversationType: ConversationType.GROUP,
  // 群聊为群组 Id，单聊为 userId，可从 conversation 中获取
  targetId: '目标 Id'
}

const info = [{
    id: 'groupMemberUserId1',
    name: '成员昵称',
    portraitUri: '成员头像',
  },
   {
    id: 'groupMemberUserId2',
    name: '成员昵称',
    portraitUri: '成员头像',
   }
]
imkit.updateGroupMembers(conversation, info)
```

**参数说明**

|       参数     | 类型   | 必填 |     说明   |
|:------------- |:-------|:--- |:---------- |
| conversation  | Object | 是  | 会话信息 |
| info          | Array  | 是  | 全量群成员信息 |

- **info 属性说明**

    |       参数     | 类型   | 必填 |     说明   |
    |:------------- |:-------|:--- |:---------- |
    | id            | string | 是  | 群成员 UserId |
    | name      | string | 否  | 群成员昵称 |
    | portraitUri   | string | 否  | 群成员头像 URI |

- **conversation 属性说明**

    | 名称             | 参数   | 必传 | 说明     |
    | ---------------- | ------ | ---- | -------- |
    | conversationType | string | 是   | 会话类型 |
    | targetId         | string | 是   | 目标 ID  |
